@@ -2,6 +2,7 @@ from gongish import Application as GongishApp
 from cytra.db import DatabaseAppMixin
 from cytra.auth import AuthAppMixin
 from cytra.cors import CORS
+from cytra.log import LogAppMixin
 
 
 class CytraAppBase(GongishApp):
@@ -31,5 +32,5 @@ class CytraAppBase(GongishApp):
         pass
 
 
-class Application(AuthAppMixin, DatabaseAppMixin, CytraAppBase):
+class Application(AuthAppMixin, DatabaseAppMixin, LogAppMixin, CytraAppBase):
     pass
