@@ -6,6 +6,7 @@ from sqlalchemy.ext.associationproxy import ASSOCIATION_PROXY
 class InspectionMixin:
     __abstract__ = True
     __cytra_inspections__: dict = None
+    __cytra_inspections_key__: str = None
 
     @classmethod
     def _update_inspections(cls):
@@ -57,8 +58,12 @@ class InspectionMixin:
 
     @classmethod
     def get_inspections(cls):
-        if cls.__cytra_inspections__ is None:
+        key = cls.__name__
+        if cls.__cytra_inspections__ is None or (
+            cls.__cytra_inspections_key__ != key
+        ):
             cls.__cytra_inspections__ = cls._update_inspections()
+            cls.__cytra_inspections_key__ = key
 
         return cls.__cytra_inspections__
 
